==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescriptionMetadata } from "./WebFilteringOperationDescriptionMetadata";
import { WebFilteringExpressionDescription } from "./WebFilteringExpressionDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionDescriptionMetadata.a == null) {
                WebFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringExpressionDescriptionMetadata.a);
            WebFilteringOperationDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("FieldName", "String");
            a.item("Condition", "ExportedType:WebFilteringOperation");
            a.item("SearchVal", "Unknown");
            a.item("IgnoreCase", "Boolean");
        }
        static d(a) {
            WebFilteringExpressionDescriptionMetadata.b(a);
            a.ad("WebFilteringExpression", () => new WebFilteringExpressionDescription());
            a.ac("WebFilteringExpression", WebFilteringExpressionDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescriptionMetadata } from "./WebFilteringOperationDescriptionMetadata";
import { WebFilteringExpressionDescription } from "./WebFilteringExpressionDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionDescriptionMetadata.a == null) {
                WebFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringExpressionDescriptionMetadata.a);
            WebFilteringOperationDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("__isTSPlainInterface", "Boolean");
            a.item("FieldName", "String");
            a.item("Condition", "ExportedType:WebFilteringOperation");
            a.item("SearchVal", "Unknown");
            a.item("IgnoreCase", "Boolean");
        }
        static d(a) {
            WebFilteringExpressionDescriptionMetadata.b(a);
            a.ae("WebFilteringExpression", () => new WebFilteringExpressionDescription());
            a.ad("WebFilteringExpression", WebFilteringExpressionDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionDescriptionMetadata;
})();
